@@ -1,9 +1,14 @@
 # MIT licensed
 # Copyright (c) 2013-2017 lilydjwg <lilydjwg@gmail.com>, et al.
 
+import os
+
 from flaky import flaky
 import pytest
-pytestmark = pytest.mark.asyncio
+pytestmark = [pytest.mark.asyncio,
+              pytest.mark.needs_net,
+              pytest.mark.skipif(os.environ.get('TRAVIS') == 'true',
+                                 reason="fail too often")]
 
 @flaky(max_runs=10)
 async def test_aur(get_version):
